Revert "update port of server" 14/96114/1
authordeng yuanhong <dengyuanhong@chinamobile.com>
Sat, 21 Sep 2019 00:41:14 +0000 (00:41 +0000)
committerdeng yuanhong <dengyuanhong@chinamobile.com>
Sat, 21 Sep 2019 00:41:14 +0000 (00:41 +0000)
This reverts commit b65c162d99d51cc4c209a82dbfc9ece13ff7e81a.

Issue-ID: MODELING-222
Change-Id: I957b9a9e09884f6aa20d6bc6b6c7f72dd62f8e33
Signed-off-by: dyh <dengyuanhong@chinamobile.com>
run.sh

diff --git a/run.sh b/run.sh
index 4bfe7e6..04b3052 100755 (executable)
--- a/run.sh
+++ b/run.sh
@@ -18,12 +18,12 @@ if [ ! -x  $logDir  ]; then
     mkdir -p $logDir
 fi
 
-nohup python manage.py runserver 0.0.0.0:8280 > /dev/null &
-# nohup uwsgi --http :8280 -t 120 --module catalog.wsgi --master --processes 4 &
+nohup python manage.py runserver 0.0.0.0:8806 > /dev/null &
+# nohup uwsgi --http :8806 -t 120 --module catalog.wsgi --master --processes 4 &
 
 
 # if [ "${SSL_ENABLED}" = "true" ]; then
#     nohup uwsgi --https :8280,catalog/pub/ssl/cert/foobar.crt,catalog/pub/ssl/cert/foobar.key, -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
 # else
#     nohup uwsgi --http :8280 -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
 # fi
@@ -18,12 +18,12 @@ if [ ! -x  $logDir  ]; then
 
 # if [ "${SSL_ENABLED}" = "true" ]; then
-#     nohup uwsgi --https :8280,catalog/pub/ssl/cert/foobar.crt,catalog/pub/ssl/cert/foobar.key, -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
+#     nohup uwsgi --https :8806,catalog/pub/ssl/cert/foobar.crt,catalog/pub/ssl/cert/foobar.key, -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
 # else
@@ -18,12 +18,12 @@ if [ ! -x  $logDir  ]; then
 # else
-#     nohup uwsgi --http :8280 -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
+#     nohup uwsgi --http :8806 -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
 # fi